import { useState, useRef, useEffect } from 'react'

import SocialLinksCell from 'src/components/Social/SocialLinksCell'

interface ContactCardProps {
  portraitUrl: string
}

const ContactCard = ({ portraitUrl }: ContactCardProps) => {
  const [width, setWidth] = useState()
  const [height, setHeight] = useState()

  const observedDiv = useRef(null)

  useEffect(() => {
    if (!observedDiv.current) return

    const resizeObserver = new ResizeObserver(() => {
      if (observedDiv.current.offsetWidth !== width)
        setWidth(observedDiv.current.offsetWidth)

      if (observedDiv.current.offsetHeight !== height)
        setHeight(observedDiv.current.offsetHeight)
    })

    resizeObserver.observe(observedDiv.current)

    return function cleanup() {
      resizeObserver.disconnect()
    }
  }, [width, height])

  return (
    <>
      <style
        dangerouslySetInnerHTML={{
          /* Tailwind arbitrary classes (e.g h-[${height}px]) doesn't work? */
          __html: `
            .contact-me-image {
              width: ${width}px;
              height: auto;

              @media (min-width: 768px) {
                width: auto;
                min-height: 18.25rem;
                height: ${height}px;
              }
            }
          `,
        }}
      />

      <div className="flex min-h-[calc(100vh-6rem)] items-center justify-center">
        <div className="card bg-base-100 shadow-xl md:card-side">
          <figure>
            <img
              className="contact-me-image aspect-portrait object-cover"
              src={portraitUrl}
              alt={`${process.env.FIRST_NAME} ${process.env.LAST_NAME}`}
            />
          </figure>
          <div
            className="card-body mx-auto h-fit w-fit md:mx-0"
            ref={observedDiv}
          >
            <h2 className="card-title justify-center text-3xl md:justify-start">
              Contact Me
            </h2>
            <p className="p-2"></p>
            <div className="card-actions">
              <SocialLinksCell />
            </div>
          </div>
        </div>
      </div>
    </>
  )
}

export default ContactCard
